import React, { useEffect, useState } from "react";
import { View, StyleSheet } from "react-native";
import Animated, { Easing, useAnimatedStyle, useSharedValue, withTiming } from "react-native-reanimated";
const styles = StyleSheet.create({
    container: {
        backgroundColor: 'green',
        overflow: 'hidden'
    }
});
const AccordionView = ({ visible, children }) => {
    const [opened, setOpened] = useState(false);
    const [bodySectionHeight, setBodySectionHeight] = useState(0);
    const viewHeight = useSharedValue(0);
    const viewStyle = useAnimatedStyle(() => {
        return {
            height: viewHeight.value
        };
    });
    useEffect(() => {
        toggleList(visible);
    }, [visible]);
    const toggleList = (show) => {
        if (!show) {
            viewHeight.value = withTiming(0, {
                duration: 500,
                easing: Easing.bezier(0.25, 0.1, 0.25, 1)
            });
            setTimeout(() => {
                setOpened(false);
            }, 500);
        }
        else {
            setOpened(true);
            viewHeight.value = withTiming(bodySectionHeight, {
                duration: 500,
                easing: Easing.bezier(0.25, 0.1, 0.25, 1)
            });
        }
    };
    return (opened ?
        <Animated.View style={[styles.container, viewStyle]}>
        <View onLayout={(ev) => {
            setBodySectionHeight(ev.nativeEvent.layout.height);
        }} style={{ position: 'absolute', bottom: 0 }}>
          {children}
        </View>
      </Animated.View>
        : null);
};
export { AccordionView };
//# sourceMappingURL=AccordionView.js.map